@@ -4,10 +4,8 @@ import asyncio
 from typing import TYPE_CHECKING, Generic, TypeVar
 
 from launart import Service
-from loguru import logger
 
-from satori.config import Config as Config
-from satori.model import Event
+from ..config import Config as Config
 
 if TYPE_CHECKING:
     from .. import App
@@ -26,6 +24,7 @@ class BaseNetwork(Generic[TConfig], Service):
         self.accounts = {}
         self.close_signal = asyncio.Event()
         self.sequence = -1
+        self.proxy_urls = []
 
     async def wait_for_available(self): ...
 
@@ -34,15 +33,3 @@ class BaseNetwork(Generic[TConfig], Service):
 
     async def connection_closed(self):
         self.close_signal.set()
-
-    def post_event(self, body: dict):
-        async def event_parse_task(raw: dict):
-            try:
-                event = Event.parse(raw)
-            except Exception as e:
-                logger.warning(f"Failed to parse event: {raw}\nCaused by {e!r}")
-            else:
-                self.sequence = event.id
-                await self.app.post(event)
-
-        return asyncio.create_task(event_parse_task(body))
